<ion-popover-view>
  <ion-content>
    <div class="list">
      <a class="item" href="" ng-click="add()" translate>
        Add All
      </a>
      <a class="item" href="" ng-click="play()" translate>
        Play All
      </a>
      <a class="item" href="" ng-click="replace()" translate>
        Replace Tracklist
      </a>
    </div>
  </ion-content>
</ion-popover-view>
